it("should load a utf-8 file with BOM", function() {
	var result = require("./bomfile");
	expect(result).toEqual("ok");
});

it("should load a css file with BOM", function() {
	var css = require("!css-loader!./bomfile.css") + "";
	expect(css).toBe("body{color:#abc}");
});
